@@ -20,6 +20,6 @@ class RoyalpackCommand(rc.Command):
             message = f"ℹ️ Royalpack [url=https://github.com/Steffo99/royalpack/]Unreleased[/url]\n"
         else:
             message = f"ℹ️ Royalpack [url=https://github.com/Steffo99/royalpack/releases/tag/{self.royalpack_version}]{self.royalpack_version}[/url]\n"
-        if "69" in semantic:
+        if "69" in self.royalpack_version:
             message += "(Nice.)"
         await data.reply(message)
