@@ -55,9 +55,7 @@ class SteammatchCommand(rc.Command):
 
     def __init__(self, interface: rc.CommandInterface):
         super().__init__(interface)
-        if "Steam" not in self.config or "web_api_key" not in self.config["Steam"]:
-            raise rc.ConfigurationError("[c]Steam.web_api_key[/c] config option is missing!")
-        self._api = steam.webapi.WebAPI(self.config["Steam"]["web_api_key"])
+        self._api = steam.webapi.WebAPI(self.config["steampowered"]["token"])
 
     async def run(self, args: rc.CommandArgs, data: rc.CommandData) -> None:
         users = []
