@@ -1,29 +1,31 @@
-from starlette.responses import *
-from royalnet.constellation.api import *
-from royalnet.utils import *
+from typing import *
+import royalnet.constellation.api as rca
+import royalnet.utils as ru
 from ..tables import *
 
 
-class ApiDiarioListStar(ApiStar):
-    path = "/api/diario/list/v1"
-
-    summary = "Get a list of up to 500 diario entries."
+class ApiDiarioPagesStar(rca.ApiStar):
+    path = "/api/diario/pages/v1"
 
     parameters = {
-        "page": "The diario page you want to get. Can be negative to get the entries in reverse order."
+        "get": {
+            "page": "The diario page you want to get. Can be negative to get the entries in reverse order."
+        }
     }
 
     tags = ["diario"]
 
-    async def api(self, data: ApiData) -> dict:
+    @rca.magic
+    async def get(self, data: rca.ApiData) -> ru.JSON:
+        """Get a diario page made of up to 500 diario entries."""
         page_str = data["page"]
         try:
             page = int(page_str)
         except ValueError:
-            raise InvalidParameterError("'page' is not a valid int.")
+            raise rca.InvalidParameterError("'page' is not a valid int.")
         if page < 0:
             page = -page-1
-            entries: typing.List[Diario] = await asyncify(
+            entries: List[Diario] = await ru.asyncify(
                 data.session
                     .query(self.alchemy.get(Diario))
                     .order_by(self.alchemy.get(Diario).diario_id.desc()).limit(500)
@@ -31,7 +33,7 @@ class ApiDiarioListStar(ApiStar):
                     .all
             )
         else:
-            entries: typing.List[Diario] = await asyncify(
+            entries: List[Diario] = await ru.asyncify(
                 data.session
                     .query(self.alchemy.get(Diario))
                     .order_by(self.alchemy.get(Diario).diario_id)
