@@ -1,7 +1,9 @@
 from .royalqueue import RoyalQueue
 from .royalpool import RoyalPool
+from .mmtask import MMTask
 
 __all__ = [
     "RoyalQueue",
     "RoyalPool",
+    "MMTask",
 ]
